@@ -33,7 +33,7 @@ import errno
 import signal
 import pwd
 import grp
-from sol.SolBase import SolBase
+from pythonsol.SolBase import SolBase
 
 SolBase.loggingInit()
 logger = logging.getLogger("Daemon")
